return {
    {
        "sainnhe/gruvbox-material",
        config = function(_, _)
            vim.o.termguicolors = true
            vim.g.background = "dark"
            vim.cmd("colorscheme gruvbox-material")
        end
    },
    {
        "lukas-reineke/indent-blankline.nvim",
        main = "ibl",
        event = "VeryLazy",
        opts = { },
    },
    {
        "famiu/bufdelete.nvim",
        keys = {
            { "zx", "<cmd>Bdelete<CR>", mode = "n" },
        },
    },
    {
        "karb94/neoscroll.nvim",
        enabled = custom.full_feature,
        main = "neoscroll",
        event = "VeryLazy",
        opts = { },
    },
    {
        "akinsho/bufferline.nvim",
        enabled = custom.full_feature,
        main = "bufferline",
        event = "VeryLazy",
        keys = {
            { "zn", "<cmd>BufferLineCycleNext<cr>" },
            { "zp", "<cmd>BufferLineCyclePrev<cr>" },
            { "zcn", "<cmd>BufferLineMoveNext<cr>" },
            { "zcp", "<cmd>BufferLineMovePrev<cr>" },
        },
        opts = {
            options = {
                numbers = "ordinal",
                diagnostics = "nvim_lsp",
                diagnostics_indicator = function(count, level, diagnostics_dict, context)
                    local icon = level:match("error") and " " or " "
                    return " " .. icon .. count
                end,
                separator_style = "thick",
                offsets = {
                    {
                        filetype = "NvimTree",
                        text = "Nvim Tree",
                        text_align = "center",
                        separator = true,
                    },
                },
                persist_buffer_sort = false,
            }
        },
    },
    {
        "nvim-lualine/lualine.nvim",
        enabled = custom.full_feature,
        dependencies = {
            "nvim-tree/nvim-web-devicons"
        },
        main = "lualine",
        event = "VeryLazy",
        opts = {
            sections = {
                lualine_a = {'mode'},
                lualine_b = {'branch', 'diff', 'diagnostics'},
                lualine_c = {'filename'},
                lualine_x = {'encoding', 'fileformat', 'filetype'},
                lualine_y = {'progress'},
                lualine_z = {'location'}
            },
            inactive_sections = {
                lualine_a = {},
                lualine_b = {},
                lualine_c = {'filename'},
                lualine_x = {'encoding', 'fileformat', 'filetype'},
                lualine_y = {'progress'},
                lualine_z = {'location'}
            }
        },
        init = function(_)
            vim.o.mousemoveevent = true
        end,
    },
    {
        "nvim-tree/nvim-tree.lua",
        enabled = custom.full_feature,
        dependencies = {
            "nvim-tree/nvim-web-devicons"
        },
        main = "nvim-tree",
        event = "VeryLazy",
        opts = {
            filters = {
                git_ignored = false,
            },
        },
        keys = {
            { "<leader>t", "<cmd>NvimTreeFocus<CR>", mode = "n" },
            { "<leader>f", "<cmd>NvimTreeFindFile<CR>", mode = "n" },
        },
        init = function(_)
            vim.g.loaded_netrw = 1
            vim.g.loaded_netrwPlugin = 1

            vim.api.nvim_create_autocmd("QuitPre", {
                callback = function()
                    local invalid_win = {}
                    local wins = vim.api.nvim_list_wins()
                    for _, w in ipairs(wins) do
                        local bufname = vim.api.nvim_buf_get_name(vim.api.nvim_win_get_buf(w))
                        if bufname:match("NvimTree_") ~= nil then
                            table.insert(invalid_win, w)
                        end
                    end
                    if #invalid_win == #wins - 1 then
                        -- Should quit, so we close all invalid windows.
                        for _, w in ipairs(invalid_win) do vim.api.nvim_win_close(w, true) end
                    end
                end
            })
        end,
    }
}

